@@ -1,8 +1,9 @@
-""" Github Merger:
-CLI to synchronize meta data of git activities of one account to another.
+""" GitMerge:
+Tool to synchronize meta data of git activities of one account to another.
 """
 
 import os
+import sys
 from datetime import datetime, timedelta
 from dateutil.relativedelta import relativedelta
 import time
@@ -10,27 +11,39 @@ import hashlib
 import re
 
 from git import Repo 
+from git.exc import InvalidGitRepositoryError
+from gitmerge.errors import InvalidRepositoryException
+from gitmerge.dirchecker import DirectoryChecker
 
 class Commit:
   
   def __init__(self, date, hexsha):
     """ Git commit with relevant information for merge.
     :param date: Commit date as datetime object.
-    :commit chash: Commit hash as identifier for commit to avoid duplicate commits.
+    :param hexsha: Commit hash as identifier for commit to avoid duplicate commits.
     """
     self.date = date
     self.hexsha = hexsha
+    self.transferred = False
     
 
 class Merger:
 
-  def __init__(self, author, src_path, dest_path, company):
+  def __init__(self, author, src_path, dest_path, company=''):
     # repos
-    self.src_repo = Repo(os.path.abspath(src_path))
-    src_name = self.src_repo.remotes.origin.url.split('.git')[0].split('/')[-1]
-    self.hashed_repo_name = hashlib.sha512(src_name.encode('utf-8')).hexdigest()[:20]
+    try:
+      self.src_repo = Repo(os.path.abspath(src_path))
+    except InvalidGitRepositoryError as e:
+      # override with customized exception and message
+      raise InvalidRepositoryException(src_path)
+      
+    self.src_name = self.src_repo.remotes.origin.url.split('.git')[0].split('/')[-1]
+    self.hashed_repo_name = hashlib.sha512(self.src_name.encode('utf-8')).hexdigest()[:20]
     
-    self.dest_repo = Repo(os.path.abspath(dest_path))
+    try:
+      self.dest_repo = Repo(os.path.abspath(dest_path))
+    except InvalidGitRepositoryError as e:
+      raise InvalidRepositoryException(dest_path)
 
     # name of commiter in src path
     self.author = author
@@ -41,7 +54,7 @@ class Merger:
     self.commits = None
 
   def __since2days(self, since):
-    """ Parses the input of since into days. """
+    """ Parses the input into days ago. """
     # default to commits of last week if None value is passed in since
     if since is None:
       since = '1w'
@@ -78,10 +91,31 @@ class Merger:
     if matched:
       return dte
 
-  def get_commits(self, since='1w'):
+  def __postprocess(self, commits):
+    """ Filter out commits that have already been transferred to the destination repo. """
+    dc = DirectoryChecker()
+    if dc.repo_exists(self.dest_repo, self.hashed_repo_name):
+      filepath = f'{self.dest_repo.working_dir}/{self.hashed_repo_name}/test.txt'
+
+      # read in already transferred commits
+      with open(filepath, 'r') as f:
+        transfers = f.readlines()
+      
+      regex = '([0-9a-f]){40}'
+      for i in range(len(transfers)-1, -1, -1):
+        m = None
+        m = re.search(regex, transfers[i])
+        if m is not None:
+          for c in commits:
+            if c.hexsha == m[0]:
+              c.transferred = True
+    return commits.reverse()
+
+  def get_commits(self, since='1w', until='0d'):
     """ Get all commits in specified range """
     # since gets converted from a string to a datetime object
     since = self.__since2days(since)
+    until = self.__since2days(until)
     # get list of commits
     commits = list(self.src_repo.iter_commits('--all'))
 
@@ -94,28 +128,21 @@ class Merger:
       iso_date = time.strftime("%Y-%m-%d %H:%M:%S +0000", time.gmtime(c.committed_date))
       
       # calc date x days ago and check if commit date is newer
-      #is_new = converted_date > datetime.now()-timedelta(days=since)
-      is_new = converted_date > since
+      is_new = converted_date >= since and converted_date <= until
+      print(converted_date)
+      print(since)
+      print(until)
 
       # filter commits based on author and if commits were committed in last x period
       if c.author.name == self.author and is_new:
         commit = Commit(iso_date, c.hexsha)
         commits_filtered.append(commit)
       
-      self.commits = commits_filtered
+    self.commits = commits_filtered
+    self.commits = self.__postprocess(commits_filtered)
 
     return commits_filtered
 
-  def preview(self, commits):
-    """ Print out a review of the commits. """ 
-    print('\tHash\tDate') 
-    max = len(commits)
-    for idx, c in enumerate(commits):
-      print(f'{idx} - {c.hexsha} | {c.date}') 
-    print('------------------------------------------------------------------')
-    print(f'{idx} total changes that can be committed / pushed')
-    print(f'Print the same statement without --list flag for committing and pushing it')
-
   def __create_directory(self):
     """ Creates directory in destination repo with hashed name and one file with headers. """
     # inspect directory structure
@@ -141,6 +168,9 @@ class Merger:
     if commits == None:
       commits = self.commits
     
+    # filter already transferred commits
+    commits = [c for c in commits if c.transferred]
+
     file_name = self.__create_directory()
     for c in commits:
       with open(file_name, 'a') as f:
